@@ -24,7 +24,6 @@ from typing import (
 )
 
 from ....utils.async_itertools import async_chain, async_chain_iterator
-from ....utils.async_tools import threaded
 from ....utils.logging import LoggingDescriptor
 from ...common.decorators import language_id, trigger_characters
 from ...common.lsp_types import (
@@ -108,7 +107,6 @@ class RobotCompletionProtocolPart(RobotLanguageServerProtocolPart):
     )
     # @all_commit_characters(['\n'])
     @language_id("robotframework")
-    @threaded()
     @_logger.call
     async def collect(
         self, sender: Any, document: TextDocument, position: Position, context: Optional[CompletionContext]
@@ -130,7 +128,6 @@ class RobotCompletionProtocolPart(RobotLanguageServerProtocolPart):
         )
 
     @language_id("robotframework")
-    @threaded()
     @_logger.call
     async def resolve(self, sender: Any, completion_item: CompletionItem) -> CompletionItem:
         if completion_item.data is not None:
